@@ -1,8 +1,8 @@
 use strict;
 
 package Path::Class::File;
-BEGIN {
-  $Path::Class::File::VERSION = '0.24';
+{
+  $Path::Class::File::VERSION = '0.25';
 }
 
 use Path::Class::Dir;
@@ -95,6 +95,12 @@ sub remove {
   return not -e $file;
 }
 
+sub traverse {
+  my $self = shift;
+  my ($callback, @args) = @_;
+  return $self->$callback(sub { () }, @args);
+}
+
 1;
 __END__
 
@@ -104,7 +110,7 @@ Path::Class::File - Objects representing files
 
 =head1 VERSION
 
-version 0.24
+version 0.25
 
 =head1 SYNOPSIS
 
@@ -315,6 +321,11 @@ a I<reading> mode.
 
 The default C<iomode> is C<r>.
 
+=item $file->traverse(sub { ... }, @args)
+
+Calls the given callback on $file. This doesn't do much on its own,
+but see the associated documentation in L<Path::Class::Dir>.
+
 =item $file->remove()
 
 This method will remove the file in a way that works well on all
@@ -352,4 +363,4 @@ Ken Williams, kwilliams@cpan.org
 
 Path::Class, Path::Class::Dir, File::Spec
 
-=cut
\ No newline at end of file
+=cut
